ete2.parser.fasta

Package ete2 :: Package parser :: Module fasta |
[hide private]
[frames] | no frames]

# Module fasta

source code

Functions | [hide private]
read_fasta(source, obj=None) Reads a collection of sequences econded in FASTA format. | source code
write_fasta(sequences, outfile=None, seqwidth=80) Writes a SeqGroup python object using FASTA format. | source code
_seq2str(seq, seqwidth=80) | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev95``'``
| __package__ = ``'``ete2.parser``'``